@@ -1,12 +1,12 @@
 package Argon::Server;
 # ABSTRACT: Base class for Argon server objects
-$Argon::Server::VERSION = '0.17';
+$Argon::Server::VERSION = '0.18';
 
 use strict;
 use warnings;
 use Carp;
 use Moose;
-use Try::Tiny;
+use Try::Catch;
 use AnyEvent;
 use AnyEvent::Socket qw(tcp_server);
 use Path::Tiny 'path';
@@ -193,7 +193,7 @@ Argon::Server - Base class for Argon server objects
 
 =head1 VERSION
 
-version 0.17
+version 0.18
 
 =head1 SYNOPSIS
 
